from mhkit.wave.io import ndbc
from mhkit.wave.io import wecsim
from mhkit.wave.io import cdip
from mhkit.wave.io import swan
try:
    from mhkit.wave.io import hindcast
except ImportError:
    print("WARNING: Wave WPTO hindcast functions not imported from"
          "MHKiT-Python. If you are using Windows and calling from"
          "MHKiT-MATLAB this is expected.")
    pass
